darkhistory.physics.photo_ion_rate — DarkHistory documentation

# darkhistory.physics.photo_ion_rate

`darkhistory.physics.` `photo_ion_rate`(rs, eng, xH, xe, atom=None)

  Photoionization rate in cm-3 s-1.

  Parameters: | rs : float Redshift (1+z). eng : ndarray Energies to evaluate the cross section. xH : float Ionization fraction nH+/nH. xe : float Ionization fraction ne/nH = nH+/nH + nHe+/nH. atom : {None,’HI’,’HeI’,’HeII’}, optional Determines which photoionization rate is returned. The default value is `None`, which returns the total rate.
  Returns: | float The photoionization rate of the particular species or the total ionization rate.

#### Previous topic

darkhistory.physics.d_xe_Saha_dz

#### Next topic

darkhistory.physics.photo_ion_xsec

### This Page

Show Source